@@ -6,15 +6,14 @@
 #'
 #' @name cctools-package
 #' @aliases cctools
-#' @docType package
 #' @useDynLib cctools, .registration = TRUE
 #'
 #' @author Thomas Nagler
 #'
 #' @references
 #' Nagler, T. (2017). *A generic approach to nonparametric function
-#' estimation with mixed data.* [arXiv:1704.07457](https://arxiv.org/pdf/1704.07457.pdf)
+#' estimation with mixed data.* [arXiv:1704.07457](https://arxiv.org/pdf/1704.07457)
 #'
 #' @keywords package
 #'
-NULL
+"_PACKAGE"
